YARP 2.3.65 (2016-05-13)                                              {#v2_3_65}
========================

[TOC]

YARP 2.3.65 Release Notes
=========================


A (partial) list of bug fixed and issues resolved in this release can be found
[here](https://github.com/robotology/yarp/issues?q=label%3A%22Fixed+in%3A+YARP+v2.3.65%22).



Important Changes
-----------------

* YARP is now automatically installed with the RPATH enabled.
  This can be disabled by setting the `CMAKE_SKIP_RPATH` or
  `CMAKE_SKIP_INSTALL_RPATH` variables.
* The `portmonitor` can now be built without LUA and uses YARP plugins system
  of having to locate the shared libraries manually.
* The `yarp::dev::IDepthSensor`, `yarp::dev::IRGBDSensor` interfaces and the
  `RGBDSensorClient` and `RGBDSensorWrapper` devices were erroneously introduced
  as a "stable", but they are still under development and therefore are not to
  be used, and will be removed in the next tweak release (v2.3.65.1).
  They will be probably re-introduced in the next stable release series
  (v2.3.68).



Bug Fixes
---------

### YARP_OS

* Fixed memory leaks when building with c++11.
* Fixed `yarp::os::Thread::getKey()` method for c++11.
* Fixed race condition in `yarp::os::Thread::getKey()`.



New Features
------------

### YARP_OS

* `ResourceFinder::configure(argc,argv,bool)` accepts a third optional parameter
  to keep/skip the first command line argument

### yarprobotinterface

The `robotInterface` tool in
[robotology/icub-main](https://github.com/robotology/icub-main/) was imported
in YARP with a few non compatible changes:

* `robotInterface` was renamed `yarprobotinterface` to follow the convention
  with yarp executables
* The RPC port opened is now /<robotname>/yarprobotinterface
* The default `.ini` file name is now `yarprobotinterface.ini`
* The DTD line for XML files is now
```xml
<!DOCTYPE [...] PUBLIC "-//YARP//DTD yarprobotinterface 1.0//EN" "http://www.yarp.it/DTD/yarprobotinterfaceV1.0.dtd">
```

### yarpmanager++

A new `yarpmanager++` tool which merges the functionalities of the `yarpmanager`
and `yarpbuilder` was added.



Deprecated Features
-------------------

### YARP_OS

* `yarp::os::Module` is now deprecated in favour of `yarp::os::RFModule`.
* `YARP_ASSERT` is now deprecated in favour of `yAssert`.

### YARP_dev

* The following YARP methods have been deprecated:
  - iPositionControl::setPositionMode()
  - iVelocityControl::setVelocityMode()
  - iTorqueControl::setTorqueMode()
  - iOpenLoopControl::setOpenLoopMode()

### Devices
* `controlboard` and `clientcontrolboard` devices are now deprecated in favour
  of `controlboardwrapper2` and `remote_controlboard`.

### Tools
* `yarpserver2` and `yarpserver3` are now considered deprecated and will be
  removed in the next release.

### GUIs
* All guis based on GTK2 are now considered deprecated and will be removed in
  the next release.



Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.64..v2.3.65`):

```
   480	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
    92	Alberto Cardellino <alberto.cardellino@iit.it>
    81	Marco Randazzo <marco.randazzo@iit.it>
    57	Ali Paikan <ali.paikan@iit.it>
    48	Ugo Pattacini <ugo.pattacini@iit.it>
    44	Lorenzo Natale <lorenzo.natale@iit.it>
    24	Francesco Romano <francesco.romano@iit.it>
    24	Silvio Traversaro <silvio.traversaro@iit.it>
    17	Matteo Brunettini <matteo.brunettini@iit.it>
    15	Vadim Tikhanoff <vadim.tikhanoff@iit.it>
     5	Giulia Vezzani <giulia.vezzani@iit.it>
     4	Alessandro Roncone <alessandro.roncone@iit.it>
     4	Elena Ceseracciu <elena.ceseracciu@iit.it>
     4	Konstantinos Theofilis <kostas@ams.eng.osaka-u.ac.jp>
     3	Davide Perrone <dperrone@aitek.it>
     3	YARP Developers <yarp0-devel@lists.sourceforge.net>
     2	Claudio Fantacci <claudio.fantacci@iit.it>
     2	Davide Pollarolo <davide.pollarolo@iit.it>
     2	Francesco Nori <francesco.nori@iit.it>
     1	Alessio Rocchi <alessio.rocchi@iit.it>
     1	Davide Tome <davide.tome@iit.it>
     1	Francesca Stramandinoli <francesca.stramandinoli@iit.it>
     1	Gabriele Nava <gabriele.nava@mail.polimi.it>
     1	Valentina Gaggero <valentina.gaggero@iit.it>
```
